Miscellaneous
==================

.. currentmodule:: daft

Types
--------------

Image Types
~~~~~~~~~~~~~~

.. autosummary::
    :nosignatures:
    :toctree: doc_gen/misc

    ImageMode
    ImageFormat
